==> ackee-frontend-toolkit-0.7.0.tgz: package/es/modules/chat/components/Messages/Message.js <==
import { React, PropTypes, moment, classnames, pure } from '../../dependencies';

export var authorShape = PropTypes.shape({
    authorId: PropTypes.string.isRequired,
    name: PropTypes.string
});

var DefaultImageComponent = function DefaultImageComponent(_ref) {
    var image = _ref.image;
    return React.createElement(
        "a",
        { href: image, target: "_blank" },
        React.createElement("img", { src: image, alt: "" })
    );
};

DefaultImageComponent.propTypes = {
    image: PropTypes.string.isRequired
};

var DefaultAuthorComponent = function DefaultAuthorComponent(_ref2) {
    var author = _ref2.author,
        seen = _ref2.seen;
    return React.createElement(
        "span",
        null,
        author.name,
        " ",
        seen ? '' : '•'
    );
};

// We want also unused props in default to have definition of props
// for AuthorComponent complete
/* eslint-disable react/no-unused-prop-types */
DefaultAuthorComponent.propTypes = {
    author: authorShape.isRequired,
    seen: PropTypes.bool.isRequired,
    isMe: PropTypes.bool.isRequired
};
/* eslint-enable-line react/no-unused-prop-types */

DefaultAuthorComponent.defaultProps = {
    name: ''
};

var Message = function Message(_ref3) {
    var author = _ref3.author,
        image = _ref3.image,
        text = _ref3.text,
        time = _ref3.time,
        seen = _ref3.seen,
        dateFormat = _ref3.dateFormat,
        amIAuthor = _ref3.amIAuthor,
        MessageAuthor = _ref3.MessageAuthor,
        MessageImage = _ref3.MessageImage;

    var date = moment(time);

    var fullDateFormat = 'HH:mm';

    if (moment().diff(date, 'days') === 0) {
        fullDateFormat += " " + dateFormat;
    }

    return React.createElement(
        "div",
        {
            className: classnames('conversation__message', { 'conversation__message--author-me': amIAuthor })
        },
        React.createElement(
            "div",
            {
                className: "conversation__message-inner"
            },
            React.createElement(
                "div",
                { className: "conversation__message-author" },
                React.createElement(MessageAuthor, {
                    author: author,
                    seen: seen,
                    isMe: amIAuthor
                })
            ),
            React.createElement(
                "div",
                { className: "conversation__message-bubble" },
                text && React.createElement(
                    "span",
                    { className: "conversation__message-text" },
                    text
                ),
                image && MessageImage,
                React.createElement(
                    "span",
                    { className: "conversation__message-date" },
                    date.format(fullDateFormat)
                )
            )
        )
    );
};

Message.propTypes = {
    author: authorShape,
    image: PropTypes.string,
    text: PropTypes.string,
    time: PropTypes.number.isRequired,
    seen: PropTypes.bool.isRequired,
    amIAuthor: PropTypes.bool.isRequired,

    MessageAuthor: PropTypes.func,
    MessageImage: PropTypes.func,
    dateFormat: PropTypes.string
};

Message.defaultProps = {
    author: {},
    image: null,
    text: null,

    MessageAuthor: DefaultAuthorComponent,
    MessageImage: DefaultImageComponent,
    dateFormat: 'DD MMM YYYY'
};

export default pure(Message);

==> ackee-frontend-toolkit-0.16.1.tgz: package/es/modules/chat/components/Messages/Message.js <==
import { React, PropTypes, moment, classnames, pure } from '../../dependencies';

export var authorShape = PropTypes.shape({
    authorId: PropTypes.string.isRequired,
    name: PropTypes.string
});

var DefaultImageComponent = function DefaultImageComponent(_ref) {
    var image = _ref.image;
    return React.createElement(
        "a",
        { href: image, target: "_blank" },
        React.createElement("img", { src: image, alt: "" })
    );
};

DefaultImageComponent.propTypes = {
    image: PropTypes.string.isRequired
};

var DefaultAuthorComponent = function DefaultAuthorComponent(_ref2) {
    var author = _ref2.author,
        seen = _ref2.seen;
    return React.createElement(
        "span",
        null,
        author.name,
        " ",
        seen ? '' : '•'
    );
};

// We want also unused props in default to have definition of props
// for AuthorComponent complete
/* eslint-disable react/no-unused-prop-types */
DefaultAuthorComponent.propTypes = {
    author: authorShape.isRequired,
    seen: PropTypes.bool.isRequired,
    isMe: PropTypes.bool.isRequired
};
/* eslint-enable-line react/no-unused-prop-types */

DefaultAuthorComponent.defaultProps = {
    name: ''
};

var Message = function Message(_ref3) {
    var author = _ref3.author,
        image = _ref3.image,
        text = _ref3.text,
        time = _ref3.time,
        seen = _ref3.seen,
        dateFormat = _ref3.dateFormat,
        amIAuthor = _ref3.amIAuthor,
        MessageAuthor = _ref3.MessageAuthor,
        MessageImage = _ref3.MessageImage;

    var date = moment(time);

    var fullDateFormat = 'HH:mm';

    if (moment().diff(date, 'days') === 0) {
        fullDateFormat += " " + dateFormat;
    }

    return React.createElement(
        "div",
        {
            className: classnames('conversation__message', {
                'conversation__message--author-me': amIAuthor
            })
        },
        React.createElement(
            "div",
            { className: "conversation__message-inner" },
            React.createElement(
                "div",
                { className: "conversation__message-author" },
                React.createElement(MessageAuthor, {
                    author: author,
                    seen: seen,
                    isMe: amIAuthor
                })
            ),
            React.createElement(
                "div",
                { className: "conversation__message-bubble" },
                text && React.createElement(
                    "span",
                    { className: "conversation__message-text" },
                    text
                ),
                image && MessageImage,
                React.createElement(
                    "span",
                    { className: "conversation__message-date" },
                    date.format(fullDateFormat)
                )
            )
        )
    );
};

Message.propTypes = {
    author: authorShape,
    image: PropTypes.string,
    text: PropTypes.string,
    time: PropTypes.number.isRequired,
    seen: PropTypes.bool.isRequired,
    amIAuthor: PropTypes.bool.isRequired,

    MessageAuthor: PropTypes.func,
    MessageImage: PropTypes.func,
    dateFormat: PropTypes.string
};

Message.defaultProps = {
    author: {},
    image: null,
    text: null,

    MessageAuthor: DefaultAuthorComponent,
    MessageImage: DefaultImageComponent,
    dateFormat: 'DD MMM YYYY'
};

export default pure()(Message);
